@@ -9,6 +9,6 @@ from .improve_dlc_output_cat_alone import improve_dlc_output_cat_alone
 from .csv2h5 import csv2h5
 from .analyze_rois import analyze_rois
 from .concat_rois import concat_rois
-from .calc_mw import calc_mw
+from .roi_calc_mw import roi_calc_mw
 
 from .version import __version__, VERSION
